@@ -141,7 +141,7 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/5.4.0.1");
+pref("calendar.useragent.extra", "Lightning/5.4");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
@@ -160,9 +160,9 @@ pref("calendar.item.editInTab", false);
 pref("calendar.item.useNewItemUI", false);
 
 // Backend to use. false: libical, true: ical.js
-//@line 166 "/build/thunderbird/src/thunderbird-52.0.1/calendar/lightning/content/lightning.js"
+//@line 166 "/build/thunderbird/src/thunderbird-52.0/calendar/lightning/content/lightning.js"
 pref("calendar.icaljs", false);
-//@line 168 "/build/thunderbird/src/thunderbird-52.0.1/calendar/lightning/content/lightning.js"
+//@line 168 "/build/thunderbird/src/thunderbird-52.0/calendar/lightning/content/lightning.js"
 
 // Calendar integration notification
 pref("calendar.integration.notify", true);
